@@ -215,6 +215,9 @@ def schema_for_column(c):
         column_schema['items'] = {'$ref': '#/definitions/sdc_recursive_string_array'}
     elif c.sql_data_type == 'uuid[]':
         column_schema['items'] = {'$ref': '#/definitions/sdc_recursive_string_array'}
+    elif c.sql_data_type == 'bytea[]':
+        # bytea[] are unsupported
+        del column_schema['type']
     else:
         #custom datatypes like enums
         column_schema['items'] = {'$ref': '#/definitions/sdc_recursive_string_array'}
@@ -273,7 +276,7 @@ WHERE attnum > 0
 AND NOT a.attisdropped
 AND pg_class.relkind IN ('r', 'v', 'm')
 AND n.nspname NOT in ('pg_toast', 'pg_catalog', 'information_schema')
-AND has_table_privilege(pg_class.oid, 'SELECT') = true """)
+AND has_column_privilege(pg_class.oid, attname, 'SELECT') = true """)
         for row in cur.fetchall():
             row_count, is_view, schema_name, table_name, *col_info = row
 
@@ -436,13 +439,6 @@ def do_discovery(conn_config):
     dump_catalog(all_streams)
     return all_streams
 
-
-def should_sync_column(md_map, field_name):
-    field_metadata = md_map.get(('properties', field_name), {})
-    return singer.should_sync_field(field_metadata.get('inclusion'),
-                                    field_metadata.get('selected'),
-                                    True)
-
 def is_selected_via_metadata(stream):
     table_md = metadata.to_map(stream['metadata']).get((), {})
     return table_md.get('selected')
@@ -500,10 +496,10 @@ def sync_method_for_streams(streams, state, default_replication_method):
         state = clear_state_on_replication_change(state, stream['tap_stream_id'], replication_key, replication_method)
 
         if replication_method not in set(['LOG_BASED', 'FULL_TABLE', 'INCREMENTAL']):
-            raise Exception("Unrecognized replication_method {}".format(replication_method))
+            raise Exception("Unrecognized replication_method {} for stream {}".format(replication_method, stream['tap_stream_id']))
 
         md_map = metadata.to_map(stream['metadata'])
-        desired_columns = [c for c in stream['schema']['properties'].keys() if should_sync_column(md_map, c)]
+        desired_columns = [c for c in stream['schema']['properties'].keys() if sync_common.should_sync_column(md_map, c)]
         desired_columns.sort()
 
         if len(desired_columns) == 0:
@@ -545,7 +541,7 @@ def sync_traditional_stream(conn_config, stream, state, sync_method, end_lsn):
     LOGGER.info("Beginning sync of stream(%s) with sync method(%s)", stream['tap_stream_id'], sync_method)
     md_map = metadata.to_map(stream['metadata'])
     conn_config['dbname'] = md_map.get(()).get('database-name')
-    desired_columns = [c for c in stream['schema']['properties'].keys() if should_sync_column(md_map, c)]
+    desired_columns = [c for c in stream['schema']['properties'].keys() if sync_common.should_sync_column(md_map, c)]
     desired_columns.sort()
 
     if len(desired_columns) == 0:
@@ -583,7 +579,7 @@ def sync_traditional_stream(conn_config, stream, state, sync_method, end_lsn):
 def sync_logical_streams(conn_config, logical_streams, state, end_lsn):
     if logical_streams:
         LOGGER.info("Pure Logical Replication upto lsn %s for (%s)", end_lsn, list(map(lambda s: s['tap_stream_id'], logical_streams)))
-        logical_streams = list(map(logical_replication.add_automatic_properties, logical_streams))
+        logical_streams = list(map(lambda s: logical_replication.add_automatic_properties(s, conn_config), logical_streams))
 
         state = logical_replication.sync_tables(conn_config, logical_streams, state, end_lsn)
 
@@ -658,8 +654,6 @@ def do_sync(conn_config, catalog, default_replication_method, state):
         end_lsn = None
 
     sync_method_lookup, traditional_streams, logical_streams = sync_method_for_streams(streams, state, default_replication_method)
-    #{"chickens" : "full_stream", "cows" : "logical_initial_interrupted_streams", "turkeys": "logical_replication"}
-    #{"logical_streams" : ["turkeys"], "traditional_streams" : ["chickens", "cows"]}
 
     if currently_syncing:
         LOGGER.info("found currently_syncing: %s", currently_syncing)
@@ -687,7 +681,9 @@ def main_impl():
                    'password' : args.config['password'],
                    'port'     : args.config['port'],
                    'dbname'   : args.config['dbname'],
-                   'filter_dbs' : args.config.get('filter_dbs')}
+                   'filter_dbs' : args.config.get('filter_dbs'),
+                   'debug_lsn' : args.config.get('debug_lsn') == 'true',
+                   'logical_poll_total_seconds': float(args.config.get('logical_poll_total_seconds', 0))}
 
     if args.config.get('ssl') == 'true':
         conn_config['sslmode'] = 'require'
